# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateRowDetails(object):
    """
    Specifications for the putting of a table row.
    """

    #: A constant which can be used with the option property of a UpdateRowDetails.
    #: This constant has a value of "IF_ABSENT"
    OPTION_IF_ABSENT = "IF_ABSENT"

    #: A constant which can be used with the option property of a UpdateRowDetails.
    #: This constant has a value of "IF_PRESENT"
    OPTION_IF_PRESENT = "IF_PRESENT"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateRowDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this UpdateRowDetails.
        :type compartment_id: str

        :param value:
            The value to assign to the value property of this UpdateRowDetails.
        :type value: dict(str, object)

        :param option:
            The value to assign to the option property of this UpdateRowDetails.
            Allowed values for this property are: "IF_ABSENT", "IF_PRESENT"
        :type option: str

        :param is_get_return_row:
            The value to assign to the is_get_return_row property of this UpdateRowDetails.
        :type is_get_return_row: bool

        :param timeout_in_ms:
            The value to assign to the timeout_in_ms property of this UpdateRowDetails.
        :type timeout_in_ms: int

        :param ttl:
            The value to assign to the ttl property of this UpdateRowDetails.
        :type ttl: int

        :param is_ttl_use_table_default:
            The value to assign to the is_ttl_use_table_default property of this UpdateRowDetails.
        :type is_ttl_use_table_default: bool

        :param identity_cache_size:
            The value to assign to the identity_cache_size property of this UpdateRowDetails.
        :type identity_cache_size: int

        :param is_exact_match:
            The value to assign to the is_exact_match property of this UpdateRowDetails.
        :type is_exact_match: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'value': 'dict(str, object)',
            'option': 'str',
            'is_get_return_row': 'bool',
            'timeout_in_ms': 'int',
            'ttl': 'int',
            'is_ttl_use_table_default': 'bool',
            'identity_cache_size': 'int',
            'is_exact_match': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'value': 'value',
            'option': 'option',
            'is_get_return_row': 'isGetReturnRow',
            'timeout_in_ms': 'timeoutInMs',
            'ttl': 'ttl',
            'is_ttl_use_table_default': 'isTtlUseTableDefault',
            'identity_cache_size': 'identityCacheSize',
            'is_exact_match': 'isExactMatch'
        }

        self._compartment_id = None
        self._value = None
        self._option = None
        self._is_get_return_row = None
        self._timeout_in_ms = None
        self._ttl = None
        self._is_ttl_use_table_default = None
        self._identity_cache_size = None
        self._is_exact_match = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this UpdateRowDetails.
        The OCID of the table's compartment.  Required
        if the tableNameOrId path parameter is a table name.
        Optional if tableNameOrId is an OCID.  If tableNameOrId
        is an OCID, and compartmentId is supplied, the latter
        must match the identified table's compartmentId.


        :return: The compartment_id of this UpdateRowDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this UpdateRowDetails.
        The OCID of the table's compartment.  Required
        if the tableNameOrId path parameter is a table name.
        Optional if tableNameOrId is an OCID.  If tableNameOrId
        is an OCID, and compartmentId is supplied, the latter
        must match the identified table's compartmentId.


        :param compartment_id: The compartment_id of this UpdateRowDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def value(self):
        """
        **[Required]** Gets the value of this UpdateRowDetails.
        The map of values from a row.


        :return: The value of this UpdateRowDetails.
        :rtype: dict(str, object)
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this UpdateRowDetails.
        The map of values from a row.


        :param value: The value of this UpdateRowDetails.
        :type: dict(str, object)
        """
        self._value = value

    @property
    def option(self):
        """
        Gets the option of this UpdateRowDetails.
        Specifies a condition for the put operation.

        Allowed values for this property are: "IF_ABSENT", "IF_PRESENT"


        :return: The option of this UpdateRowDetails.
        :rtype: str
        """
        return self._option

    @option.setter
    def option(self, option):
        """
        Sets the option of this UpdateRowDetails.
        Specifies a condition for the put operation.


        :param option: The option of this UpdateRowDetails.
        :type: str
        """
        allowed_values = ["IF_ABSENT", "IF_PRESENT"]
        if not value_allowed_none_or_none_sentinel(option, allowed_values):
            raise ValueError(
                "Invalid value for `option`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._option = option

    @property
    def is_get_return_row(self):
        """
        Gets the is_get_return_row of this UpdateRowDetails.
        If true, and the put fails due to an option setting, then
        the existing row will be returned.


        :return: The is_get_return_row of this UpdateRowDetails.
        :rtype: bool
        """
        return self._is_get_return_row

    @is_get_return_row.setter
    def is_get_return_row(self, is_get_return_row):
        """
        Sets the is_get_return_row of this UpdateRowDetails.
        If true, and the put fails due to an option setting, then
        the existing row will be returned.


        :param is_get_return_row: The is_get_return_row of this UpdateRowDetails.
        :type: bool
        """
        self._is_get_return_row = is_get_return_row

    @property
    def timeout_in_ms(self):
        """
        Gets the timeout_in_ms of this UpdateRowDetails.
        Timeout setting for the put.


        :return: The timeout_in_ms of this UpdateRowDetails.
        :rtype: int
        """
        return self._timeout_in_ms

    @timeout_in_ms.setter
    def timeout_in_ms(self, timeout_in_ms):
        """
        Sets the timeout_in_ms of this UpdateRowDetails.
        Timeout setting for the put.


        :param timeout_in_ms: The timeout_in_ms of this UpdateRowDetails.
        :type: int
        """
        self._timeout_in_ms = timeout_in_ms

    @property
    def ttl(self):
        """
        Gets the ttl of this UpdateRowDetails.
        Time-to-live for the row, in days.


        :return: The ttl of this UpdateRowDetails.
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """
        Sets the ttl of this UpdateRowDetails.
        Time-to-live for the row, in days.


        :param ttl: The ttl of this UpdateRowDetails.
        :type: int
        """
        self._ttl = ttl

    @property
    def is_ttl_use_table_default(self):
        """
        Gets the is_ttl_use_table_default of this UpdateRowDetails.
        If true, set time-to-live for this row to the table's default.


        :return: The is_ttl_use_table_default of this UpdateRowDetails.
        :rtype: bool
        """
        return self._is_ttl_use_table_default

    @is_ttl_use_table_default.setter
    def is_ttl_use_table_default(self, is_ttl_use_table_default):
        """
        Sets the is_ttl_use_table_default of this UpdateRowDetails.
        If true, set time-to-live for this row to the table's default.


        :param is_ttl_use_table_default: The is_ttl_use_table_default of this UpdateRowDetails.
        :type: bool
        """
        self._is_ttl_use_table_default = is_ttl_use_table_default

    @property
    def identity_cache_size(self):
        """
        Gets the identity_cache_size of this UpdateRowDetails.
        Sets the number of generated identity values that are
        requested from the server during a put. If present and greater than 0,
        this value takes precedence over a default value for the table.


        :return: The identity_cache_size of this UpdateRowDetails.
        :rtype: int
        """
        return self._identity_cache_size

    @identity_cache_size.setter
    def identity_cache_size(self, identity_cache_size):
        """
        Sets the identity_cache_size of this UpdateRowDetails.
        Sets the number of generated identity values that are
        requested from the server during a put. If present and greater than 0,
        this value takes precedence over a default value for the table.


        :param identity_cache_size: The identity_cache_size of this UpdateRowDetails.
        :type: int
        """
        self._identity_cache_size = identity_cache_size

    @property
    def is_exact_match(self):
        """
        Gets the is_exact_match of this UpdateRowDetails.
        If present and true, the presented row value must exactly
        match the table's schema.  Otherwise, rows with missing
        non-key fields or extra fields can be written successfully.


        :return: The is_exact_match of this UpdateRowDetails.
        :rtype: bool
        """
        return self._is_exact_match

    @is_exact_match.setter
    def is_exact_match(self, is_exact_match):
        """
        Sets the is_exact_match of this UpdateRowDetails.
        If present and true, the presented row value must exactly
        match the table's schema.  Otherwise, rows with missing
        non-key fields or extra fields can be written successfully.


        :param is_exact_match: The is_exact_match of this UpdateRowDetails.
        :type: bool
        """
        self._is_exact_match = is_exact_match

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParseConnectionDetails(object):
    """
    Parse connections from the connection metadata and oracle wallet file.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParseConnectionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param connection_detail:
            The value to assign to the connection_detail property of this ParseConnectionDetails.
        :type connection_detail: Connection

        :param connection_payload:
            The value to assign to the connection_payload property of this ParseConnectionDetails.
        :type connection_payload: str

        """
        self.swagger_types = {
            'connection_detail': 'Connection',
            'connection_payload': 'str'
        }

        self.attribute_map = {
            'connection_detail': 'connectionDetail',
            'connection_payload': 'connectionPayload'
        }

        self._connection_detail = None
        self._connection_payload = None

    @property
    def connection_detail(self):
        """
        Gets the connection_detail of this ParseConnectionDetails.

        :return: The connection_detail of this ParseConnectionDetails.
        :rtype: Connection
        """
        return self._connection_detail

    @connection_detail.setter
    def connection_detail(self, connection_detail):
        """
        Sets the connection_detail of this ParseConnectionDetails.

        :param connection_detail: The connection_detail of this ParseConnectionDetails.
        :type: Connection
        """
        self._connection_detail = connection_detail

    @property
    def connection_payload(self):
        """
        Gets the connection_payload of this ParseConnectionDetails.
        The information used to parse the connection from the wallet file payload.


        :return: The connection_payload of this ParseConnectionDetails.
        :rtype: str
        """
        return self._connection_payload

    @connection_payload.setter
    def connection_payload(self, connection_payload):
        """
        Sets the connection_payload of this ParseConnectionDetails.
        The information used to parse the connection from the wallet file payload.


        :param connection_payload: The connection_payload of this ParseConnectionDetails.
        :type: str
        """
        self._connection_payload = connection_payload

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsAssociation(object):
    """
    LogAnalyticsAssociation
    """

    #: A constant which can be used with the life_cycle_state property of a LogAnalyticsAssociation.
    #: This constant has a value of "ACCEPTED"
    LIFE_CYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the life_cycle_state property of a LogAnalyticsAssociation.
    #: This constant has a value of "IN_PROGRESS"
    LIFE_CYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the life_cycle_state property of a LogAnalyticsAssociation.
    #: This constant has a value of "SUCCEEDED"
    LIFE_CYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the life_cycle_state property of a LogAnalyticsAssociation.
    #: This constant has a value of "FAILED"
    LIFE_CYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsAssociation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param failure_message:
            The value to assign to the failure_message property of this LogAnalyticsAssociation.
        :type failure_message: str

        :param agent_id:
            The value to assign to the agent_id property of this LogAnalyticsAssociation.
        :type agent_id: str

        :param time_last_attempted:
            The value to assign to the time_last_attempted property of this LogAnalyticsAssociation.
        :type time_last_attempted: datetime

        :param retry_count:
            The value to assign to the retry_count property of this LogAnalyticsAssociation.
        :type retry_count: int

        :param source_name:
            The value to assign to the source_name property of this LogAnalyticsAssociation.
        :type source_name: str

        :param source_display_name:
            The value to assign to the source_display_name property of this LogAnalyticsAssociation.
        :type source_display_name: str

        :param source_type_name:
            The value to assign to the source_type_name property of this LogAnalyticsAssociation.
        :type source_type_name: str

        :param life_cycle_state:
            The value to assign to the life_cycle_state property of this LogAnalyticsAssociation.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type life_cycle_state: str

        :param entity_id:
            The value to assign to the entity_id property of this LogAnalyticsAssociation.
        :type entity_id: str

        :param entity_name:
            The value to assign to the entity_name property of this LogAnalyticsAssociation.
        :type entity_name: str

        :param entity_type_name:
            The value to assign to the entity_type_name property of this LogAnalyticsAssociation.
        :type entity_type_name: str

        :param host:
            The value to assign to the host property of this LogAnalyticsAssociation.
        :type host: str

        :param agent_entity_name:
            The value to assign to the agent_entity_name property of this LogAnalyticsAssociation.
        :type agent_entity_name: str

        :param entity_type_display_name:
            The value to assign to the entity_type_display_name property of this LogAnalyticsAssociation.
        :type entity_type_display_name: str

        :param log_group_id:
            The value to assign to the log_group_id property of this LogAnalyticsAssociation.
        :type log_group_id: str

        :param log_group_name:
            The value to assign to the log_group_name property of this LogAnalyticsAssociation.
        :type log_group_name: str

        :param log_group_compartment:
            The value to assign to the log_group_compartment property of this LogAnalyticsAssociation.
        :type log_group_compartment: str

        """
        self.swagger_types = {
            'failure_message': 'str',
            'agent_id': 'str',
            'time_last_attempted': 'datetime',
            'retry_count': 'int',
            'source_name': 'str',
            'source_display_name': 'str',
            'source_type_name': 'str',
            'life_cycle_state': 'str',
            'entity_id': 'str',
            'entity_name': 'str',
            'entity_type_name': 'str',
            'host': 'str',
            'agent_entity_name': 'str',
            'entity_type_display_name': 'str',
            'log_group_id': 'str',
            'log_group_name': 'str',
            'log_group_compartment': 'str'
        }

        self.attribute_map = {
            'failure_message': 'failureMessage',
            'agent_id': 'agentId',
            'time_last_attempted': 'timeLastAttempted',
            'retry_count': 'retryCount',
            'source_name': 'sourceName',
            'source_display_name': 'sourceDisplayName',
            'source_type_name': 'sourceTypeName',
            'life_cycle_state': 'lifeCycleState',
            'entity_id': 'entityId',
            'entity_name': 'entityName',
            'entity_type_name': 'entityTypeName',
            'host': 'host',
            'agent_entity_name': 'agentEntityName',
            'entity_type_display_name': 'entityTypeDisplayName',
            'log_group_id': 'logGroupId',
            'log_group_name': 'logGroupName',
            'log_group_compartment': 'logGroupCompartment'
        }

        self._failure_message = None
        self._agent_id = None
        self._time_last_attempted = None
        self._retry_count = None
        self._source_name = None
        self._source_display_name = None
        self._source_type_name = None
        self._life_cycle_state = None
        self._entity_id = None
        self._entity_name = None
        self._entity_type_name = None
        self._host = None
        self._agent_entity_name = None
        self._entity_type_display_name = None
        self._log_group_id = None
        self._log_group_name = None
        self._log_group_compartment = None

    @property
    def failure_message(self):
        """
        Gets the failure_message of this LogAnalyticsAssociation.
        failure message


        :return: The failure_message of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._failure_message

    @failure_message.setter
    def failure_message(self, failure_message):
        """
        Sets the failure_message of this LogAnalyticsAssociation.
        failure message


        :param failure_message: The failure_message of this LogAnalyticsAssociation.
        :type: str
        """
        self._failure_message = failure_message

    @property
    def agent_id(self):
        """
        Gets the agent_id of this LogAnalyticsAssociation.
        Lama Idf


        :return: The agent_id of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """
        Sets the agent_id of this LogAnalyticsAssociation.
        Lama Idf


        :param agent_id: The agent_id of this LogAnalyticsAssociation.
        :type: str
        """
        self._agent_id = agent_id

    @property
    def time_last_attempted(self):
        """
        Gets the time_last_attempted of this LogAnalyticsAssociation.
        last attempt date


        :return: The time_last_attempted of this LogAnalyticsAssociation.
        :rtype: datetime
        """
        return self._time_last_attempted

    @time_last_attempted.setter
    def time_last_attempted(self, time_last_attempted):
        """
        Sets the time_last_attempted of this LogAnalyticsAssociation.
        last attempt date


        :param time_last_attempted: The time_last_attempted of this LogAnalyticsAssociation.
        :type: datetime
        """
        self._time_last_attempted = time_last_attempted

    @property
    def retry_count(self):
        """
        Gets the retry_count of this LogAnalyticsAssociation.
        retry count


        :return: The retry_count of this LogAnalyticsAssociation.
        :rtype: int
        """
        return self._retry_count

    @retry_count.setter
    def retry_count(self, retry_count):
        """
        Sets the retry_count of this LogAnalyticsAssociation.
        retry count


        :param retry_count: The retry_count of this LogAnalyticsAssociation.
        :type: int
        """
        self._retry_count = retry_count

    @property
    def source_name(self):
        """
        Gets the source_name of this LogAnalyticsAssociation.
        source name


        :return: The source_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this LogAnalyticsAssociation.
        source name


        :param source_name: The source_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._source_name = source_name

    @property
    def source_display_name(self):
        """
        Gets the source_display_name of this LogAnalyticsAssociation.
        source display name


        :return: The source_display_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._source_display_name

    @source_display_name.setter
    def source_display_name(self, source_display_name):
        """
        Sets the source_display_name of this LogAnalyticsAssociation.
        source display name


        :param source_display_name: The source_display_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._source_display_name = source_display_name

    @property
    def source_type_name(self):
        """
        Gets the source_type_name of this LogAnalyticsAssociation.
        source type internal name


        :return: The source_type_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._source_type_name

    @source_type_name.setter
    def source_type_name(self, source_type_name):
        """
        Sets the source_type_name of this LogAnalyticsAssociation.
        source type internal name


        :param source_type_name: The source_type_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._source_type_name = source_type_name

    @property
    def life_cycle_state(self):
        """
        Gets the life_cycle_state of this LogAnalyticsAssociation.
        lifeCycleState

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The life_cycle_state of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._life_cycle_state

    @life_cycle_state.setter
    def life_cycle_state(self, life_cycle_state):
        """
        Sets the life_cycle_state of this LogAnalyticsAssociation.
        lifeCycleState


        :param life_cycle_state: The life_cycle_state of this LogAnalyticsAssociation.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(life_cycle_state, allowed_values):
            life_cycle_state = 'UNKNOWN_ENUM_VALUE'
        self._life_cycle_state = life_cycle_state

    @property
    def entity_id(self):
        """
        Gets the entity_id of this LogAnalyticsAssociation.
        entity GUID


        :return: The entity_id of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this LogAnalyticsAssociation.
        entity GUID


        :param entity_id: The entity_id of this LogAnalyticsAssociation.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def entity_name(self):
        """
        Gets the entity_name of this LogAnalyticsAssociation.
        entity name


        :return: The entity_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this LogAnalyticsAssociation.
        entity name


        :param entity_name: The entity_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def entity_type_name(self):
        """
        Gets the entity_type_name of this LogAnalyticsAssociation.
        entity type internal name


        :return: The entity_type_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._entity_type_name

    @entity_type_name.setter
    def entity_type_name(self, entity_type_name):
        """
        Sets the entity_type_name of this LogAnalyticsAssociation.
        entity type internal name


        :param entity_type_name: The entity_type_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._entity_type_name = entity_type_name

    @property
    def host(self):
        """
        Gets the host of this LogAnalyticsAssociation.
        host name


        :return: The host of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this LogAnalyticsAssociation.
        host name


        :param host: The host of this LogAnalyticsAssociation.
        :type: str
        """
        self._host = host

    @property
    def agent_entity_name(self):
        """
        Gets the agent_entity_name of this LogAnalyticsAssociation.
        Agent entity name


        :return: The agent_entity_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._agent_entity_name

    @agent_entity_name.setter
    def agent_entity_name(self, agent_entity_name):
        """
        Sets the agent_entity_name of this LogAnalyticsAssociation.
        Agent entity name


        :param agent_entity_name: The agent_entity_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._agent_entity_name = agent_entity_name

    @property
    def entity_type_display_name(self):
        """
        Gets the entity_type_display_name of this LogAnalyticsAssociation.
        entity type display name


        :return: The entity_type_display_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._entity_type_display_name

    @entity_type_display_name.setter
    def entity_type_display_name(self, entity_type_display_name):
        """
        Sets the entity_type_display_name of this LogAnalyticsAssociation.
        entity type display name


        :param entity_type_display_name: The entity_type_display_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._entity_type_display_name = entity_type_display_name

    @property
    def log_group_id(self):
        """
        Gets the log_group_id of this LogAnalyticsAssociation.
        log group ocid


        :return: The log_group_id of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        """
        Sets the log_group_id of this LogAnalyticsAssociation.
        log group ocid


        :param log_group_id: The log_group_id of this LogAnalyticsAssociation.
        :type: str
        """
        self._log_group_id = log_group_id

    @property
    def log_group_name(self):
        """
        Gets the log_group_name of this LogAnalyticsAssociation.
        log group name


        :return: The log_group_name of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._log_group_name

    @log_group_name.setter
    def log_group_name(self, log_group_name):
        """
        Sets the log_group_name of this LogAnalyticsAssociation.
        log group name


        :param log_group_name: The log_group_name of this LogAnalyticsAssociation.
        :type: str
        """
        self._log_group_name = log_group_name

    @property
    def log_group_compartment(self):
        """
        Gets the log_group_compartment of this LogAnalyticsAssociation.
        log group compartment


        :return: The log_group_compartment of this LogAnalyticsAssociation.
        :rtype: str
        """
        return self._log_group_compartment

    @log_group_compartment.setter
    def log_group_compartment(self, log_group_compartment):
        """
        Sets the log_group_compartment of this LogAnalyticsAssociation.
        log group compartment


        :param log_group_compartment: The log_group_compartment of this LogAnalyticsAssociation.
        :type: str
        """
        self._log_group_compartment = log_group_compartment

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FolderSummary(object):
    """
    The folder summary type contains the audit summary information and the definition of the folder.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FolderSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this FolderSummary.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this FolderSummary.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this FolderSummary.
        :type model_version: str

        :param name:
            The value to assign to the name property of this FolderSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this FolderSummary.
        :type description: str

        :param category_name:
            The value to assign to the category_name property of this FolderSummary.
        :type category_name: str

        :param object_status:
            The value to assign to the object_status property of this FolderSummary.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this FolderSummary.
        :type identifier: str

        :param parent_ref:
            The value to assign to the parent_ref property of this FolderSummary.
        :type parent_ref: ParentReference

        :param object_version:
            The value to assign to the object_version property of this FolderSummary.
        :type object_version: int

        :param metadata:
            The value to assign to the metadata property of this FolderSummary.
        :type metadata: ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this FolderSummary.
        :type key_map: dict(str, str)

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'category_name': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'parent_ref': 'ParentReference',
            'object_version': 'int',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'category_name': 'categoryName',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parent_ref': 'parentRef',
            'object_version': 'objectVersion',
            'metadata': 'metadata',
            'key_map': 'keyMap'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._name = None
        self._description = None
        self._category_name = None
        self._object_status = None
        self._identifier = None
        self._parent_ref = None
        self._object_version = None
        self._metadata = None
        self._key_map = None

    @property
    def key(self):
        """
        Gets the key of this FolderSummary.
        Generated key that can be used in API calls to identify folder.


        :return: The key of this FolderSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this FolderSummary.
        Generated key that can be used in API calls to identify folder.


        :param key: The key of this FolderSummary.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this FolderSummary.
        The type of the object.


        :return: The model_type of this FolderSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this FolderSummary.
        The type of the object.


        :param model_type: The model_type of this FolderSummary.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this FolderSummary.
        The model version of an object.


        :return: The model_version of this FolderSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this FolderSummary.
        The model version of an object.


        :param model_version: The model_version of this FolderSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this FolderSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :return: The name of this FolderSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FolderSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :param name: The name of this FolderSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this FolderSummary.
        Detailed description for the object.


        :return: The description of this FolderSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FolderSummary.
        Detailed description for the object.


        :param description: The description of this FolderSummary.
        :type: str
        """
        self._description = description

    @property
    def category_name(self):
        """
        Gets the category_name of this FolderSummary.
        categoryName


        :return: The category_name of this FolderSummary.
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """
        Sets the category_name of this FolderSummary.
        categoryName


        :param category_name: The category_name of this FolderSummary.
        :type: str
        """
        self._category_name = category_name

    @property
    def object_status(self):
        """
        Gets the object_status of this FolderSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this FolderSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this FolderSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this FolderSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this FolderSummary.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :return: The identifier of this FolderSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this FolderSummary.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :param identifier: The identifier of this FolderSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this FolderSummary.

        :return: The parent_ref of this FolderSummary.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this FolderSummary.

        :param parent_ref: The parent_ref of this FolderSummary.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def object_version(self):
        """
        Gets the object_version of this FolderSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this FolderSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this FolderSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this FolderSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def metadata(self):
        """
        Gets the metadata of this FolderSummary.

        :return: The metadata of this FolderSummary.
        :rtype: ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this FolderSummary.

        :param metadata: The metadata of this FolderSummary.
        :type: ObjectMetadata
        """
        self._metadata = metadata

    @property
    def key_map(self):
        """
        Gets the key_map of this FolderSummary.
        A map, if provided key is replaced with generated key, this structure provides mapping between user provided key and generated key


        :return: The key_map of this FolderSummary.
        :rtype: dict(str, str)
        """
        return self._key_map

    @key_map.setter
    def key_map(self, key_map):
        """
        Sets the key_map of this FolderSummary.
        A map, if provided key is replaced with generated key, this structure provides mapping between user provided key and generated key


        :param key_map: The key_map of this FolderSummary.
        :type: dict(str, str)
        """
        self._key_map = key_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DedicatedVmHostInstanceSummary(object):
    """
    Condensed instance data when listing instances on a dedicated VM host.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DedicatedVmHostInstanceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this DedicatedVmHostInstanceSummary.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DedicatedVmHostInstanceSummary.
        :type compartment_id: str

        :param instance_id:
            The value to assign to the instance_id property of this DedicatedVmHostInstanceSummary.
        :type instance_id: str

        :param shape:
            The value to assign to the shape property of this DedicatedVmHostInstanceSummary.
        :type shape: str

        :param time_created:
            The value to assign to the time_created property of this DedicatedVmHostInstanceSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'instance_id': 'str',
            'shape': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'instance_id': 'instanceId',
            'shape': 'shape',
            'time_created': 'timeCreated'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._instance_id = None
        self._shape = None
        self._time_created = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this DedicatedVmHostInstanceSummary.
        The availability domain the virtual machine instance is running in.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this DedicatedVmHostInstanceSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this DedicatedVmHostInstanceSummary.
        The availability domain the virtual machine instance is running in.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this DedicatedVmHostInstanceSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DedicatedVmHostInstanceSummary.
        The OCID of the compartment that contains the virtual machine instance.


        :return: The compartment_id of this DedicatedVmHostInstanceSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DedicatedVmHostInstanceSummary.
        The OCID of the compartment that contains the virtual machine instance.


        :param compartment_id: The compartment_id of this DedicatedVmHostInstanceSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this DedicatedVmHostInstanceSummary.
        The OCID of the virtual machine instance.


        :return: The instance_id of this DedicatedVmHostInstanceSummary.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this DedicatedVmHostInstanceSummary.
        The OCID of the virtual machine instance.


        :param instance_id: The instance_id of this DedicatedVmHostInstanceSummary.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this DedicatedVmHostInstanceSummary.
        The shape of the VM instance.


        :return: The shape of this DedicatedVmHostInstanceSummary.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this DedicatedVmHostInstanceSummary.
        The shape of the VM instance.


        :param shape: The shape of this DedicatedVmHostInstanceSummary.
        :type: str
        """
        self._shape = shape

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DedicatedVmHostInstanceSummary.
        The date and time the virtual machine instance was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this DedicatedVmHostInstanceSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DedicatedVmHostInstanceSummary.
        The date and time the virtual machine instance was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this DedicatedVmHostInstanceSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ByoipAllocatedRangeSummary(object):
    """
    Subrange of ByoipRange which is allocated to a PublicIpPool
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ByoipAllocatedRangeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cidr_block:
            The value to assign to the cidr_block property of this ByoipAllocatedRangeSummary.
        :type cidr_block: str

        :param public_ip_pool_id:
            The value to assign to the public_ip_pool_id property of this ByoipAllocatedRangeSummary.
        :type public_ip_pool_id: str

        """
        self.swagger_types = {
            'cidr_block': 'str',
            'public_ip_pool_id': 'str'
        }

        self.attribute_map = {
            'cidr_block': 'cidrBlock',
            'public_ip_pool_id': 'publicIpPoolId'
        }

        self._cidr_block = None
        self._public_ip_pool_id = None

    @property
    def cidr_block(self):
        """
        Gets the cidr_block of this ByoipAllocatedRangeSummary.
        The address range part of the ByoipRange which is used for a publicIpPool.


        :return: The cidr_block of this ByoipAllocatedRangeSummary.
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """
        Sets the cidr_block of this ByoipAllocatedRangeSummary.
        The address range part of the ByoipRange which is used for a publicIpPool.


        :param cidr_block: The cidr_block of this ByoipAllocatedRangeSummary.
        :type: str
        """
        self._cidr_block = cidr_block

    @property
    def public_ip_pool_id(self):
        """
        Gets the public_ip_pool_id of this ByoipAllocatedRangeSummary.
        The OCID of the PublicIpPool containing the part of the Byoip range.


        :return: The public_ip_pool_id of this ByoipAllocatedRangeSummary.
        :rtype: str
        """
        return self._public_ip_pool_id

    @public_ip_pool_id.setter
    def public_ip_pool_id(self, public_ip_pool_id):
        """
        Sets the public_ip_pool_id of this ByoipAllocatedRangeSummary.
        The OCID of the PublicIpPool containing the part of the Byoip range.


        :param public_ip_pool_id: The public_ip_pool_id of this ByoipAllocatedRangeSummary.
        :type: str
        """
        self._public_ip_pool_id = public_ip_pool_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConfigSource(object):
    """
    Information about the Terraform configuration.
    """

    #: A constant which can be used with the config_source_type property of a ConfigSource.
    #: This constant has a value of "ZIP_UPLOAD"
    CONFIG_SOURCE_TYPE_ZIP_UPLOAD = "ZIP_UPLOAD"

    #: A constant which can be used with the config_source_type property of a ConfigSource.
    #: This constant has a value of "GIT_CONFIG_SOURCE"
    CONFIG_SOURCE_TYPE_GIT_CONFIG_SOURCE = "GIT_CONFIG_SOURCE"

    #: A constant which can be used with the config_source_type property of a ConfigSource.
    #: This constant has a value of "COMPARTMENT_CONFIG_SOURCE"
    CONFIG_SOURCE_TYPE_COMPARTMENT_CONFIG_SOURCE = "COMPARTMENT_CONFIG_SOURCE"

    def __init__(self, **kwargs):
        """
        Initializes a new ConfigSource object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.resource_manager.models.GitConfigSource`
        * :class:`~oci.resource_manager.models.CompartmentConfigSource`
        * :class:`~oci.resource_manager.models.ZipUploadConfigSource`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_source_type:
            The value to assign to the config_source_type property of this ConfigSource.
            Allowed values for this property are: "ZIP_UPLOAD", "GIT_CONFIG_SOURCE", "COMPARTMENT_CONFIG_SOURCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type config_source_type: str

        :param working_directory:
            The value to assign to the working_directory property of this ConfigSource.
        :type working_directory: str

        """
        self.swagger_types = {
            'config_source_type': 'str',
            'working_directory': 'str'
        }

        self.attribute_map = {
            'config_source_type': 'configSourceType',
            'working_directory': 'workingDirectory'
        }

        self._config_source_type = None
        self._working_directory = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['configSourceType']

        if type == 'GIT_CONFIG_SOURCE':
            return 'GitConfigSource'

        if type == 'COMPARTMENT_CONFIG_SOURCE':
            return 'CompartmentConfigSource'

        if type == 'ZIP_UPLOAD':
            return 'ZipUploadConfigSource'
        else:
            return 'ConfigSource'

    @property
    def config_source_type(self):
        """
        **[Required]** Gets the config_source_type of this ConfigSource.
        The type of configuration source to use for the Terraform configuration.

        Allowed values for this property are: "ZIP_UPLOAD", "GIT_CONFIG_SOURCE", "COMPARTMENT_CONFIG_SOURCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The config_source_type of this ConfigSource.
        :rtype: str
        """
        return self._config_source_type

    @config_source_type.setter
    def config_source_type(self, config_source_type):
        """
        Sets the config_source_type of this ConfigSource.
        The type of configuration source to use for the Terraform configuration.


        :param config_source_type: The config_source_type of this ConfigSource.
        :type: str
        """
        allowed_values = ["ZIP_UPLOAD", "GIT_CONFIG_SOURCE", "COMPARTMENT_CONFIG_SOURCE"]
        if not value_allowed_none_or_none_sentinel(config_source_type, allowed_values):
            config_source_type = 'UNKNOWN_ENUM_VALUE'
        self._config_source_type = config_source_type

    @property
    def working_directory(self):
        """
        Gets the working_directory of this ConfigSource.
        File path to the directory to use for running Terraform.
        If not specified, the root directory is used.
        This parameter is ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.


        :return: The working_directory of this ConfigSource.
        :rtype: str
        """
        return self._working_directory

    @working_directory.setter
    def working_directory(self, working_directory):
        """
        Sets the working_directory of this ConfigSource.
        File path to the directory to use for running Terraform.
        If not specified, the root directory is used.
        This parameter is ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.


        :param working_directory: The working_directory of this ConfigSource.
        :type: str
        """
        self._working_directory = working_directory

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTransferPackageDetails(object):
    """
    CreateTransferPackageDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTransferPackageDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param original_package_delivery_tracking_number:
            The value to assign to the original_package_delivery_tracking_number property of this CreateTransferPackageDetails.
        :type original_package_delivery_tracking_number: str

        :param return_package_delivery_tracking_number:
            The value to assign to the return_package_delivery_tracking_number property of this CreateTransferPackageDetails.
        :type return_package_delivery_tracking_number: str

        :param package_delivery_vendor:
            The value to assign to the package_delivery_vendor property of this CreateTransferPackageDetails.
        :type package_delivery_vendor: str

        """
        self.swagger_types = {
            'original_package_delivery_tracking_number': 'str',
            'return_package_delivery_tracking_number': 'str',
            'package_delivery_vendor': 'str'
        }

        self.attribute_map = {
            'original_package_delivery_tracking_number': 'originalPackageDeliveryTrackingNumber',
            'return_package_delivery_tracking_number': 'returnPackageDeliveryTrackingNumber',
            'package_delivery_vendor': 'packageDeliveryVendor'
        }

        self._original_package_delivery_tracking_number = None
        self._return_package_delivery_tracking_number = None
        self._package_delivery_vendor = None

    @property
    def original_package_delivery_tracking_number(self):
        """
        Gets the original_package_delivery_tracking_number of this CreateTransferPackageDetails.

        :return: The original_package_delivery_tracking_number of this CreateTransferPackageDetails.
        :rtype: str
        """
        return self._original_package_delivery_tracking_number

    @original_package_delivery_tracking_number.setter
    def original_package_delivery_tracking_number(self, original_package_delivery_tracking_number):
        """
        Sets the original_package_delivery_tracking_number of this CreateTransferPackageDetails.

        :param original_package_delivery_tracking_number: The original_package_delivery_tracking_number of this CreateTransferPackageDetails.
        :type: str
        """
        self._original_package_delivery_tracking_number = original_package_delivery_tracking_number

    @property
    def return_package_delivery_tracking_number(self):
        """
        Gets the return_package_delivery_tracking_number of this CreateTransferPackageDetails.

        :return: The return_package_delivery_tracking_number of this CreateTransferPackageDetails.
        :rtype: str
        """
        return self._return_package_delivery_tracking_number

    @return_package_delivery_tracking_number.setter
    def return_package_delivery_tracking_number(self, return_package_delivery_tracking_number):
        """
        Sets the return_package_delivery_tracking_number of this CreateTransferPackageDetails.

        :param return_package_delivery_tracking_number: The return_package_delivery_tracking_number of this CreateTransferPackageDetails.
        :type: str
        """
        self._return_package_delivery_tracking_number = return_package_delivery_tracking_number

    @property
    def package_delivery_vendor(self):
        """
        Gets the package_delivery_vendor of this CreateTransferPackageDetails.

        :return: The package_delivery_vendor of this CreateTransferPackageDetails.
        :rtype: str
        """
        return self._package_delivery_vendor

    @package_delivery_vendor.setter
    def package_delivery_vendor(self, package_delivery_vendor):
        """
        Sets the package_delivery_vendor of this CreateTransferPackageDetails.

        :param package_delivery_vendor: The package_delivery_vendor of this CreateTransferPackageDetails.
        :type: str
        """
        self._package_delivery_vendor = package_delivery_vendor

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .configuration import Configuration
from .configuration_aggregation import ConfigurationAggregation
from .dimension import Dimension
from .filter import Filter
from .request_summarized_usages_details import RequestSummarizedUsagesDetails
from .tag import Tag
from .usage_aggregation import UsageAggregation
from .usage_summary import UsageSummary

# Maps type names to classes for usage_api services.
usage_api_type_mapping = {
    "Configuration": Configuration,
    "ConfigurationAggregation": ConfigurationAggregation,
    "Dimension": Dimension,
    "Filter": Filter,
    "RequestSummarizedUsagesDetails": RequestSummarizedUsagesDetails,
    "Tag": Tag,
    "UsageAggregation": UsageAggregation,
    "UsageSummary": UsageSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrimaryKey(object):
    """
    The primary key object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PrimaryKey object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this PrimaryKey.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this PrimaryKey.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this PrimaryKey.
        :type parent_ref: ParentReference

        :param name:
            The value to assign to the name property of this PrimaryKey.
        :type name: str

        :param attribute_refs:
            The value to assign to the attribute_refs property of this PrimaryKey.
        :type attribute_refs: list[KeyAttribute]

        :param object_status:
            The value to assign to the object_status property of this PrimaryKey.
        :type object_status: int

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'attribute_refs': 'list[KeyAttribute]',
            'object_status': 'int'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'attribute_refs': 'attributeRefs',
            'object_status': 'objectStatus'
        }

        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._attribute_refs = None
        self._object_status = None

    @property
    def key(self):
        """
        Gets the key of this PrimaryKey.
        The key of the object.


        :return: The key of this PrimaryKey.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this PrimaryKey.
        The key of the object.


        :param key: The key of this PrimaryKey.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this PrimaryKey.
        The model version of an object.


        :return: The model_version of this PrimaryKey.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this PrimaryKey.
        The model version of an object.


        :param model_version: The model_version of this PrimaryKey.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this PrimaryKey.

        :return: The parent_ref of this PrimaryKey.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this PrimaryKey.

        :param parent_ref: The parent_ref of this PrimaryKey.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this PrimaryKey.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :return: The name of this PrimaryKey.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PrimaryKey.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :param name: The name of this PrimaryKey.
        :type: str
        """
        self._name = name

    @property
    def attribute_refs(self):
        """
        Gets the attribute_refs of this PrimaryKey.
        attributeRefs


        :return: The attribute_refs of this PrimaryKey.
        :rtype: list[KeyAttribute]
        """
        return self._attribute_refs

    @attribute_refs.setter
    def attribute_refs(self, attribute_refs):
        """
        Sets the attribute_refs of this PrimaryKey.
        attributeRefs


        :param attribute_refs: The attribute_refs of this PrimaryKey.
        :type: list[KeyAttribute]
        """
        self._attribute_refs = attribute_refs

    @property
    def object_status(self):
        """
        Gets the object_status of this PrimaryKey.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this PrimaryKey.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this PrimaryKey.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this PrimaryKey.
        :type: int
        """
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsConfigWorkRequestPayload(object):
    """
    LogAnalyticsConfigWorkRequestPayload
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsConfigWorkRequestPayload object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_name:
            The value to assign to the source_name property of this LogAnalyticsConfigWorkRequestPayload.
        :type source_name: str

        :param entity_id:
            The value to assign to the entity_id property of this LogAnalyticsConfigWorkRequestPayload.
        :type entity_id: str

        :param lookup_reference:
            The value to assign to the lookup_reference property of this LogAnalyticsConfigWorkRequestPayload.
        :type lookup_reference: int

        """
        self.swagger_types = {
            'source_name': 'str',
            'entity_id': 'str',
            'lookup_reference': 'int'
        }

        self.attribute_map = {
            'source_name': 'sourceName',
            'entity_id': 'entityId',
            'lookup_reference': 'lookupReference'
        }

        self._source_name = None
        self._entity_id = None
        self._lookup_reference = None

    @property
    def source_name(self):
        """
        Gets the source_name of this LogAnalyticsConfigWorkRequestPayload.
        sourceName


        :return: The source_name of this LogAnalyticsConfigWorkRequestPayload.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this LogAnalyticsConfigWorkRequestPayload.
        sourceName


        :param source_name: The source_name of this LogAnalyticsConfigWorkRequestPayload.
        :type: str
        """
        self._source_name = source_name

    @property
    def entity_id(self):
        """
        Gets the entity_id of this LogAnalyticsConfigWorkRequestPayload.
        entityId


        :return: The entity_id of this LogAnalyticsConfigWorkRequestPayload.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this LogAnalyticsConfigWorkRequestPayload.
        entityId


        :param entity_id: The entity_id of this LogAnalyticsConfigWorkRequestPayload.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def lookup_reference(self):
        """
        Gets the lookup_reference of this LogAnalyticsConfigWorkRequestPayload.
        lookupReference


        :return: The lookup_reference of this LogAnalyticsConfigWorkRequestPayload.
        :rtype: int
        """
        return self._lookup_reference

    @lookup_reference.setter
    def lookup_reference(self, lookup_reference):
        """
        Sets the lookup_reference of this LogAnalyticsConfigWorkRequestPayload.
        lookupReference


        :param lookup_reference: The lookup_reference of this LogAnalyticsConfigWorkRequestPayload.
        :type: int
        """
        self._lookup_reference = lookup_reference

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnnouncementsCollection(object):
    """
    A list of announcements that match filter criteria, if any. Results contain both the announcements and the user-specific status of the announcements.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnnouncementsCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this AnnouncementsCollection.
        :type items: list[AnnouncementSummary]

        :param user_statuses:
            The value to assign to the user_statuses property of this AnnouncementsCollection.
        :type user_statuses: list[AnnouncementUserStatusDetails]

        """
        self.swagger_types = {
            'items': 'list[AnnouncementSummary]',
            'user_statuses': 'list[AnnouncementUserStatusDetails]'
        }

        self.attribute_map = {
            'items': 'items',
            'user_statuses': 'userStatuses'
        }

        self._items = None
        self._user_statuses = None

    @property
    def items(self):
        """
        Gets the items of this AnnouncementsCollection.
        A collection of announcements.


        :return: The items of this AnnouncementsCollection.
        :rtype: list[AnnouncementSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this AnnouncementsCollection.
        A collection of announcements.


        :param items: The items of this AnnouncementsCollection.
        :type: list[AnnouncementSummary]
        """
        self._items = items

    @property
    def user_statuses(self):
        """
        Gets the user_statuses of this AnnouncementsCollection.
        The user-specific status for found announcements.


        :return: The user_statuses of this AnnouncementsCollection.
        :rtype: list[AnnouncementUserStatusDetails]
        """
        return self._user_statuses

    @user_statuses.setter
    def user_statuses(self, user_statuses):
        """
        Sets the user_statuses of this AnnouncementsCollection.
        The user-specific status for found announcements.


        :param user_statuses: The user_statuses of this AnnouncementsCollection.
        :type: list[AnnouncementUserStatusDetails]
        """
        self._user_statuses = user_statuses

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SteeringPolicyAttachmentSummary(object):
    """
    An attachment between a steering policy and a domain.
    """

    #: A constant which can be used with the lifecycle_state property of a SteeringPolicyAttachmentSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SteeringPolicyAttachmentSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SteeringPolicyAttachmentSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    def __init__(self, **kwargs):
        """
        Initializes a new SteeringPolicyAttachmentSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param steering_policy_id:
            The value to assign to the steering_policy_id property of this SteeringPolicyAttachmentSummary.
        :type steering_policy_id: str

        :param zone_id:
            The value to assign to the zone_id property of this SteeringPolicyAttachmentSummary.
        :type zone_id: str

        :param domain_name:
            The value to assign to the domain_name property of this SteeringPolicyAttachmentSummary.
        :type domain_name: str

        :param display_name:
            The value to assign to the display_name property of this SteeringPolicyAttachmentSummary.
        :type display_name: str

        :param rtypes:
            The value to assign to the rtypes property of this SteeringPolicyAttachmentSummary.
        :type rtypes: list[str]

        :param compartment_id:
            The value to assign to the compartment_id property of this SteeringPolicyAttachmentSummary.
        :type compartment_id: str

        :param _self:
            The value to assign to the _self property of this SteeringPolicyAttachmentSummary.
        :type _self: str

        :param id:
            The value to assign to the id property of this SteeringPolicyAttachmentSummary.
        :type id: str

        :param time_created:
            The value to assign to the time_created property of this SteeringPolicyAttachmentSummary.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SteeringPolicyAttachmentSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'steering_policy_id': 'str',
            'zone_id': 'str',
            'domain_name': 'str',
            'display_name': 'str',
            'rtypes': 'list[str]',
            'compartment_id': 'str',
            '_self': 'str',
            'id': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'steering_policy_id': 'steeringPolicyId',
            'zone_id': 'zoneId',
            'domain_name': 'domainName',
            'display_name': 'displayName',
            'rtypes': 'rtypes',
            'compartment_id': 'compartmentId',
            '_self': 'self',
            'id': 'id',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState'
        }

        self._steering_policy_id = None
        self._zone_id = None
        self._domain_name = None
        self._display_name = None
        self._rtypes = None
        self._compartment_id = None
        self.__self = None
        self._id = None
        self._time_created = None
        self._lifecycle_state = None

    @property
    def steering_policy_id(self):
        """
        Gets the steering_policy_id of this SteeringPolicyAttachmentSummary.
        The OCID of the attached steering policy.


        :return: The steering_policy_id of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self._steering_policy_id

    @steering_policy_id.setter
    def steering_policy_id(self, steering_policy_id):
        """
        Sets the steering_policy_id of this SteeringPolicyAttachmentSummary.
        The OCID of the attached steering policy.


        :param steering_policy_id: The steering_policy_id of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        self._steering_policy_id = steering_policy_id

    @property
    def zone_id(self):
        """
        Gets the zone_id of this SteeringPolicyAttachmentSummary.
        The OCID of the attached zone.


        :return: The zone_id of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """
        Sets the zone_id of this SteeringPolicyAttachmentSummary.
        The OCID of the attached zone.


        :param zone_id: The zone_id of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        self._zone_id = zone_id

    @property
    def domain_name(self):
        """
        Gets the domain_name of this SteeringPolicyAttachmentSummary.
        The attached domain within the attached zone.


        :return: The domain_name of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """
        Sets the domain_name of this SteeringPolicyAttachmentSummary.
        The attached domain within the attached zone.


        :param domain_name: The domain_name of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        self._domain_name = domain_name

    @property
    def display_name(self):
        """
        Gets the display_name of this SteeringPolicyAttachmentSummary.
        A user-friendly name for the steering policy attachment.
        Does not have to be unique and can be changed.
        Avoid entering confidential information.


        :return: The display_name of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SteeringPolicyAttachmentSummary.
        A user-friendly name for the steering policy attachment.
        Does not have to be unique and can be changed.
        Avoid entering confidential information.


        :param display_name: The display_name of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def rtypes(self):
        """
        Gets the rtypes of this SteeringPolicyAttachmentSummary.
        The record types covered by the attachment at the domain. The set of record types is
        determined by aggregating the record types from the answers defined in the steering
        policy.


        :return: The rtypes of this SteeringPolicyAttachmentSummary.
        :rtype: list[str]
        """
        return self._rtypes

    @rtypes.setter
    def rtypes(self, rtypes):
        """
        Sets the rtypes of this SteeringPolicyAttachmentSummary.
        The record types covered by the attachment at the domain. The set of record types is
        determined by aggregating the record types from the answers defined in the steering
        policy.


        :param rtypes: The rtypes of this SteeringPolicyAttachmentSummary.
        :type: list[str]
        """
        self._rtypes = rtypes

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this SteeringPolicyAttachmentSummary.
        The OCID of the compartment containing the steering policy attachment.


        :return: The compartment_id of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SteeringPolicyAttachmentSummary.
        The OCID of the compartment containing the steering policy attachment.


        :param compartment_id: The compartment_id of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def _self(self):
        """
        Gets the _self of this SteeringPolicyAttachmentSummary.
        The canonical absolute URL of the resource.


        :return: The _self of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """
        Sets the _self of this SteeringPolicyAttachmentSummary.
        The canonical absolute URL of the resource.


        :param _self: The _self of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        self.__self = _self

    @property
    def id(self):
        """
        Gets the id of this SteeringPolicyAttachmentSummary.
        The OCID of the resource.


        :return: The id of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SteeringPolicyAttachmentSummary.
        The OCID of the resource.


        :param id: The id of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        self._id = id

    @property
    def time_created(self):
        """
        Gets the time_created of this SteeringPolicyAttachmentSummary.
        The date and time the resource was created, expressed in RFC 3339 timestamp format.

        **Example:** `2016-07-22T17:23:59:60Z`


        :return: The time_created of this SteeringPolicyAttachmentSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SteeringPolicyAttachmentSummary.
        The date and time the resource was created, expressed in RFC 3339 timestamp format.

        **Example:** `2016-07-22T17:23:59:60Z`


        :param time_created: The time_created of this SteeringPolicyAttachmentSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this SteeringPolicyAttachmentSummary.
        The current state of the resource.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SteeringPolicyAttachmentSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SteeringPolicyAttachmentSummary.
        The current state of the resource.


        :param lifecycle_state: The lifecycle_state of this SteeringPolicyAttachmentSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateProblemStatusDetails(object):
    """
    The additional details for the problem
    """

    #: A constant which can be used with the status property of a UpdateProblemStatusDetails.
    #: This constant has a value of "OPEN"
    STATUS_OPEN = "OPEN"

    #: A constant which can be used with the status property of a UpdateProblemStatusDetails.
    #: This constant has a value of "RESOLVED"
    STATUS_RESOLVED = "RESOLVED"

    #: A constant which can be used with the status property of a UpdateProblemStatusDetails.
    #: This constant has a value of "DISMISSED"
    STATUS_DISMISSED = "DISMISSED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateProblemStatusDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param status:
            The value to assign to the status property of this UpdateProblemStatusDetails.
            Allowed values for this property are: "OPEN", "RESOLVED", "DISMISSED"
        :type status: str

        :param comment:
            The value to assign to the comment property of this UpdateProblemStatusDetails.
        :type comment: str

        """
        self.swagger_types = {
            'status': 'str',
            'comment': 'str'
        }

        self.attribute_map = {
            'status': 'status',
            'comment': 'comment'
        }

        self._status = None
        self._comment = None

    @property
    def status(self):
        """
        **[Required]** Gets the status of this UpdateProblemStatusDetails.
        Action taken by user

        Allowed values for this property are: "OPEN", "RESOLVED", "DISMISSED"


        :return: The status of this UpdateProblemStatusDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UpdateProblemStatusDetails.
        Action taken by user


        :param status: The status of this UpdateProblemStatusDetails.
        :type: str
        """
        allowed_values = ["OPEN", "RESOLVED", "DISMISSED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            raise ValueError(
                "Invalid value for `status`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def comment(self):
        """
        Gets the comment of this UpdateProblemStatusDetails.
        User Comments


        :return: The comment of this UpdateProblemStatusDetails.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """
        Sets the comment of this UpdateProblemStatusDetails.
        User Comments


        :param comment: The comment of this UpdateProblemStatusDetails.
        :type: str
        """
        self._comment = comment

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateFunctionDetails(object):
    """
    Properties to create a new function.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateFunctionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateFunctionDetails.
        :type display_name: str

        :param application_id:
            The value to assign to the application_id property of this CreateFunctionDetails.
        :type application_id: str

        :param image:
            The value to assign to the image property of this CreateFunctionDetails.
        :type image: str

        :param image_digest:
            The value to assign to the image_digest property of this CreateFunctionDetails.
        :type image_digest: str

        :param memory_in_mbs:
            The value to assign to the memory_in_mbs property of this CreateFunctionDetails.
        :type memory_in_mbs: int

        :param config:
            The value to assign to the config property of this CreateFunctionDetails.
        :type config: dict(str, str)

        :param timeout_in_seconds:
            The value to assign to the timeout_in_seconds property of this CreateFunctionDetails.
        :type timeout_in_seconds: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateFunctionDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateFunctionDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'application_id': 'str',
            'image': 'str',
            'image_digest': 'str',
            'memory_in_mbs': 'int',
            'config': 'dict(str, str)',
            'timeout_in_seconds': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'application_id': 'applicationId',
            'image': 'image',
            'image_digest': 'imageDigest',
            'memory_in_mbs': 'memoryInMBs',
            'config': 'config',
            'timeout_in_seconds': 'timeoutInSeconds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._application_id = None
        self._image = None
        self._image_digest = None
        self._memory_in_mbs = None
        self._config = None
        self._timeout_in_seconds = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateFunctionDetails.
        The display name of the function. The display name must be unique within the application containing the function. Avoid entering confidential information.


        :return: The display_name of this CreateFunctionDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateFunctionDetails.
        The display name of the function. The display name must be unique within the application containing the function. Avoid entering confidential information.


        :param display_name: The display_name of this CreateFunctionDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def application_id(self):
        """
        **[Required]** Gets the application_id of this CreateFunctionDetails.
        The OCID of the application this function belongs to.


        :return: The application_id of this CreateFunctionDetails.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this CreateFunctionDetails.
        The OCID of the application this function belongs to.


        :param application_id: The application_id of this CreateFunctionDetails.
        :type: str
        """
        self._application_id = application_id

    @property
    def image(self):
        """
        **[Required]** Gets the image of this CreateFunctionDetails.
        The qualified name of the Docker image to use in the function, including the image tag.
        The image should be in the OCI Registry that is in the same region as the function itself.
        Example: `phx.ocir.io/ten/functions/function:0.0.1`


        :return: The image of this CreateFunctionDetails.
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """
        Sets the image of this CreateFunctionDetails.
        The qualified name of the Docker image to use in the function, including the image tag.
        The image should be in the OCI Registry that is in the same region as the function itself.
        Example: `phx.ocir.io/ten/functions/function:0.0.1`


        :param image: The image of this CreateFunctionDetails.
        :type: str
        """
        self._image = image

    @property
    def image_digest(self):
        """
        Gets the image_digest of this CreateFunctionDetails.
        The image digest for the version of the image that will be pulled when invoking this function.
        If no value is specified, the digest currently associated with the image in the OCI Registry will be used.
        Example: `sha256:ca0eeb6fb05351dfc8759c20733c91def84cb8007aa89a5bf606bc8b315b9fc7`


        :return: The image_digest of this CreateFunctionDetails.
        :rtype: str
        """
        return self._image_digest

    @image_digest.setter
    def image_digest(self, image_digest):
        """
        Sets the image_digest of this CreateFunctionDetails.
        The image digest for the version of the image that will be pulled when invoking this function.
        If no value is specified, the digest currently associated with the image in the OCI Registry will be used.
        Example: `sha256:ca0eeb6fb05351dfc8759c20733c91def84cb8007aa89a5bf606bc8b315b9fc7`


        :param image_digest: The image_digest of this CreateFunctionDetails.
        :type: str
        """
        self._image_digest = image_digest

    @property
    def memory_in_mbs(self):
        """
        **[Required]** Gets the memory_in_mbs of this CreateFunctionDetails.
        Maximum usable memory for the function (MiB).


        :return: The memory_in_mbs of this CreateFunctionDetails.
        :rtype: int
        """
        return self._memory_in_mbs

    @memory_in_mbs.setter
    def memory_in_mbs(self, memory_in_mbs):
        """
        Sets the memory_in_mbs of this CreateFunctionDetails.
        Maximum usable memory for the function (MiB).


        :param memory_in_mbs: The memory_in_mbs of this CreateFunctionDetails.
        :type: int
        """
        self._memory_in_mbs = memory_in_mbs

    @property
    def config(self):
        """
        Gets the config of this CreateFunctionDetails.
        Function configuration. These values are passed on to the function as environment variables, this overrides application configuration values.
        Keys must be ASCII strings consisting solely of letters, digits, and the '_' (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.

        Example: `{\"MY_FUNCTION_CONFIG\": \"ConfVal\"}`

        The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.


        :return: The config of this CreateFunctionDetails.
        :rtype: dict(str, str)
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this CreateFunctionDetails.
        Function configuration. These values are passed on to the function as environment variables, this overrides application configuration values.
        Keys must be ASCII strings consisting solely of letters, digits, and the '_' (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.

        Example: `{\"MY_FUNCTION_CONFIG\": \"ConfVal\"}`

        The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.


        :param config: The config of this CreateFunctionDetails.
        :type: dict(str, str)
        """
        self._config = config

    @property
    def timeout_in_seconds(self):
        """
        Gets the timeout_in_seconds of this CreateFunctionDetails.
        Timeout for executions of the function. Value in seconds.


        :return: The timeout_in_seconds of this CreateFunctionDetails.
        :rtype: int
        """
        return self._timeout_in_seconds

    @timeout_in_seconds.setter
    def timeout_in_seconds(self, timeout_in_seconds):
        """
        Sets the timeout_in_seconds of this CreateFunctionDetails.
        Timeout for executions of the function. Value in seconds.


        :param timeout_in_seconds: The timeout_in_seconds of this CreateFunctionDetails.
        :type: int
        """
        self._timeout_in_seconds = timeout_in_seconds

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateFunctionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateFunctionDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateFunctionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateFunctionDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateFunctionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateFunctionDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateFunctionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateFunctionDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateIncident(object):
    """
    Details gathered during the creation of the support ticket.

    **Caution:** Avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the problem_type property of a CreateIncident.
    #: This constant has a value of "LIMIT"
    PROBLEM_TYPE_LIMIT = "LIMIT"

    #: A constant which can be used with the problem_type property of a CreateIncident.
    #: This constant has a value of "LEGACY_LIMIT"
    PROBLEM_TYPE_LEGACY_LIMIT = "LEGACY_LIMIT"

    #: A constant which can be used with the problem_type property of a CreateIncident.
    #: This constant has a value of "TECH"
    PROBLEM_TYPE_TECH = "TECH"

    #: A constant which can be used with the problem_type property of a CreateIncident.
    #: This constant has a value of "ACCOUNT"
    PROBLEM_TYPE_ACCOUNT = "ACCOUNT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateIncident object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateIncident.
        :type compartment_id: str

        :param ticket:
            The value to assign to the ticket property of this CreateIncident.
        :type ticket: CreateTicketDetails

        :param csi:
            The value to assign to the csi property of this CreateIncident.
        :type csi: str

        :param problem_type:
            The value to assign to the problem_type property of this CreateIncident.
            Allowed values for this property are: "LIMIT", "LEGACY_LIMIT", "TECH", "ACCOUNT"
        :type problem_type: str

        :param contacts:
            The value to assign to the contacts property of this CreateIncident.
        :type contacts: list[Contact]

        :param referrer:
            The value to assign to the referrer property of this CreateIncident.
        :type referrer: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'ticket': 'CreateTicketDetails',
            'csi': 'str',
            'problem_type': 'str',
            'contacts': 'list[Contact]',
            'referrer': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'ticket': 'ticket',
            'csi': 'csi',
            'problem_type': 'problemType',
            'contacts': 'contacts',
            'referrer': 'referrer'
        }

        self._compartment_id = None
        self._ticket = None
        self._csi = None
        self._problem_type = None
        self._contacts = None
        self._referrer = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateIncident.
        The OCID of the tenancy.


        :return: The compartment_id of this CreateIncident.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateIncident.
        The OCID of the tenancy.


        :param compartment_id: The compartment_id of this CreateIncident.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def ticket(self):
        """
        **[Required]** Gets the ticket of this CreateIncident.

        :return: The ticket of this CreateIncident.
        :rtype: CreateTicketDetails
        """
        return self._ticket

    @ticket.setter
    def ticket(self, ticket):
        """
        Sets the ticket of this CreateIncident.

        :param ticket: The ticket of this CreateIncident.
        :type: CreateTicketDetails
        """
        self._ticket = ticket

    @property
    def csi(self):
        """
        Gets the csi of this CreateIncident.
        The Customer Support Identifier number for the support account.


        :return: The csi of this CreateIncident.
        :rtype: str
        """
        return self._csi

    @csi.setter
    def csi(self, csi):
        """
        Sets the csi of this CreateIncident.
        The Customer Support Identifier number for the support account.


        :param csi: The csi of this CreateIncident.
        :type: str
        """
        self._csi = csi

    @property
    def problem_type(self):
        """
        **[Required]** Gets the problem_type of this CreateIncident.
        The kind of support ticket, such as a technical issue request.

        Allowed values for this property are: "LIMIT", "LEGACY_LIMIT", "TECH", "ACCOUNT"


        :return: The problem_type of this CreateIncident.
        :rtype: str
        """
        return self._problem_type

    @problem_type.setter
    def problem_type(self, problem_type):
        """
        Sets the problem_type of this CreateIncident.
        The kind of support ticket, such as a technical issue request.


        :param problem_type: The problem_type of this CreateIncident.
        :type: str
        """
        allowed_values = ["LIMIT", "LEGACY_LIMIT", "TECH", "ACCOUNT"]
        if not value_allowed_none_or_none_sentinel(problem_type, allowed_values):
            raise ValueError(
                "Invalid value for `problem_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._problem_type = problem_type

    @property
    def contacts(self):
        """
        Gets the contacts of this CreateIncident.
        The list of contacts.


        :return: The contacts of this CreateIncident.
        :rtype: list[Contact]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """
        Sets the contacts of this CreateIncident.
        The list of contacts.


        :param contacts: The contacts of this CreateIncident.
        :type: list[Contact]
        """
        self._contacts = contacts

    @property
    def referrer(self):
        """
        Gets the referrer of this CreateIncident.
        The incident referrer. This value is often the URL that the customer used when creating the support ticket.


        :return: The referrer of this CreateIncident.
        :rtype: str
        """
        return self._referrer

    @referrer.setter
    def referrer(self, referrer):
        """
        Sets the referrer of this CreateIncident.
        The incident referrer. This value is often the URL that the customer used when creating the support ticket.


        :param referrer: The referrer of this CreateIncident.
        :type: str
        """
        self._referrer = referrer

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDbHomeBase(object):
    """
    Details for creating a Database Home.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "NONE"
    SOURCE_NONE = "NONE"

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "DB_BACKUP"
    SOURCE_DB_BACKUP = "DB_BACKUP"

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "DATABASE"
    SOURCE_DATABASE = "DATABASE"

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "VM_CLUSTER_NEW"
    SOURCE_VM_CLUSTER_NEW = "VM_CLUSTER_NEW"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDbHomeBase object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.CreateDbHomeWithDbSystemIdFromDatabaseDetails`
        * :class:`~oci.database.models.CreateDbHomeWithDbSystemIdFromBackupDetails`
        * :class:`~oci.database.models.CreateDbHomeWithDbSystemIdDetails`
        * :class:`~oci.database.models.CreateDbHomeWithVmClusterIdDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateDbHomeBase.
        :type display_name: str

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this CreateDbHomeBase.
        :type database_software_image_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDbHomeBase.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDbHomeBase.
        :type defined_tags: dict(str, dict(str, object))

        :param source:
            The value to assign to the source property of this CreateDbHomeBase.
            Allowed values for this property are: "NONE", "DB_BACKUP", "DATABASE", "VM_CLUSTER_NEW"
        :type source: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'database_software_image_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'source': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'database_software_image_id': 'databaseSoftwareImageId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'source': 'source'
        }

        self._display_name = None
        self._database_software_image_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._source = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['source']

        if type == 'DATABASE':
            return 'CreateDbHomeWithDbSystemIdFromDatabaseDetails'

        if type == 'DB_BACKUP':
            return 'CreateDbHomeWithDbSystemIdFromBackupDetails'

        if type == 'NONE':
            return 'CreateDbHomeWithDbSystemIdDetails'

        if type == 'VM_CLUSTER_NEW':
            return 'CreateDbHomeWithVmClusterIdDetails'
        else:
            return 'CreateDbHomeBase'

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateDbHomeBase.
        The user-provided name of the Database Home.


        :return: The display_name of this CreateDbHomeBase.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDbHomeBase.
        The user-provided name of the Database Home.


        :param display_name: The display_name of this CreateDbHomeBase.
        :type: str
        """
        self._display_name = display_name

    @property
    def database_software_image_id(self):
        """
        Gets the database_software_image_id of this CreateDbHomeBase.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_software_image_id of this CreateDbHomeBase.
        :rtype: str
        """
        return self._database_software_image_id

    @database_software_image_id.setter
    def database_software_image_id(self, database_software_image_id):
        """
        Sets the database_software_image_id of this CreateDbHomeBase.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_software_image_id: The database_software_image_id of this CreateDbHomeBase.
        :type: str
        """
        self._database_software_image_id = database_software_image_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDbHomeBase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateDbHomeBase.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDbHomeBase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateDbHomeBase.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDbHomeBase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateDbHomeBase.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDbHomeBase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateDbHomeBase.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def source(self):
        """
        Gets the source of this CreateDbHomeBase.
        The source of database: NONE for creating a new database. DB_BACKUP for creating a new database by restoring from a database backup.

        Allowed values for this property are: "NONE", "DB_BACKUP", "DATABASE", "VM_CLUSTER_NEW"


        :return: The source of this CreateDbHomeBase.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this CreateDbHomeBase.
        The source of database: NONE for creating a new database. DB_BACKUP for creating a new database by restoring from a database backup.


        :param source: The source of this CreateDbHomeBase.
        :type: str
        """
        allowed_values = ["NONE", "DB_BACKUP", "DATABASE", "VM_CLUSTER_NEW"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            raise ValueError(
                "Invalid value for `source`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._source = source

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Identity(object):
    """
    A container object for identity attributes.

    Example:

    -----
    {
    \"principalName\": \"ExampleName\",
    \"principalId\": \"ocid1.user.oc1..<unique_ID>\",
    \"authType\": \"natv\",
    \"callerName\": null,
    \"callerId\": null,
    \"tenantId\": \"ocid1.tenancy.oc1..<unique_ID>\",
    \"ipAddress\": \"172.24.80.88\",
    \"credentials\": null,
    \"userAgent\": \"Jersey/2.23 (HttpUrlConnection 1.8.0_212)\",
    \"consoleSessionId\": null
    }
    -----
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Identity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param principal_name:
            The value to assign to the principal_name property of this Identity.
        :type principal_name: str

        :param principal_id:
            The value to assign to the principal_id property of this Identity.
        :type principal_id: str

        :param auth_type:
            The value to assign to the auth_type property of this Identity.
        :type auth_type: str

        :param caller_name:
            The value to assign to the caller_name property of this Identity.
        :type caller_name: str

        :param caller_id:
            The value to assign to the caller_id property of this Identity.
        :type caller_id: str

        :param tenant_id:
            The value to assign to the tenant_id property of this Identity.
        :type tenant_id: str

        :param ip_address:
            The value to assign to the ip_address property of this Identity.
        :type ip_address: str

        :param credentials:
            The value to assign to the credentials property of this Identity.
        :type credentials: str

        :param user_agent:
            The value to assign to the user_agent property of this Identity.
        :type user_agent: str

        :param console_session_id:
            The value to assign to the console_session_id property of this Identity.
        :type console_session_id: str

        """
        self.swagger_types = {
            'principal_name': 'str',
            'principal_id': 'str',
            'auth_type': 'str',
            'caller_name': 'str',
            'caller_id': 'str',
            'tenant_id': 'str',
            'ip_address': 'str',
            'credentials': 'str',
            'user_agent': 'str',
            'console_session_id': 'str'
        }

        self.attribute_map = {
            'principal_name': 'principalName',
            'principal_id': 'principalId',
            'auth_type': 'authType',
            'caller_name': 'callerName',
            'caller_id': 'callerId',
            'tenant_id': 'tenantId',
            'ip_address': 'ipAddress',
            'credentials': 'credentials',
            'user_agent': 'userAgent',
            'console_session_id': 'consoleSessionId'
        }

        self._principal_name = None
        self._principal_id = None
        self._auth_type = None
        self._caller_name = None
        self._caller_id = None
        self._tenant_id = None
        self._ip_address = None
        self._credentials = None
        self._user_agent = None
        self._console_session_id = None

    @property
    def principal_name(self):
        """
        Gets the principal_name of this Identity.
        The name of the user or service. This value is the friendly name associated with `principalId`.

        Example: `ExampleName`


        :return: The principal_name of this Identity.
        :rtype: str
        """
        return self._principal_name

    @principal_name.setter
    def principal_name(self, principal_name):
        """
        Sets the principal_name of this Identity.
        The name of the user or service. This value is the friendly name associated with `principalId`.

        Example: `ExampleName`


        :param principal_name: The principal_name of this Identity.
        :type: str
        """
        self._principal_name = principal_name

    @property
    def principal_id(self):
        """
        Gets the principal_id of this Identity.
        The `OCID`__ of the principal.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The principal_id of this Identity.
        :rtype: str
        """
        return self._principal_id

    @principal_id.setter
    def principal_id(self, principal_id):
        """
        Sets the principal_id of this Identity.
        The `OCID`__ of the principal.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param principal_id: The principal_id of this Identity.
        :type: str
        """
        self._principal_id = principal_id

    @property
    def auth_type(self):
        """
        Gets the auth_type of this Identity.
        The type of authentication used.

        Example: `natv`


        :return: The auth_type of this Identity.
        :rtype: str
        """
        return self._auth_type

    @auth_type.setter
    def auth_type(self, auth_type):
        """
        Sets the auth_type of this Identity.
        The type of authentication used.

        Example: `natv`


        :param auth_type: The auth_type of this Identity.
        :type: str
        """
        self._auth_type = auth_type

    @property
    def caller_name(self):
        """
        Gets the caller_name of this Identity.
        The name of the user or service. This value is the friendly name associated with `callerId`.


        :return: The caller_name of this Identity.
        :rtype: str
        """
        return self._caller_name

    @caller_name.setter
    def caller_name(self, caller_name):
        """
        Sets the caller_name of this Identity.
        The name of the user or service. This value is the friendly name associated with `callerId`.


        :param caller_name: The caller_name of this Identity.
        :type: str
        """
        self._caller_name = caller_name

    @property
    def caller_id(self):
        """
        Gets the caller_id of this Identity.
        The `OCID`__ of the caller. The caller that made a
        request on behalf of the prinicpal.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The caller_id of this Identity.
        :rtype: str
        """
        return self._caller_id

    @caller_id.setter
    def caller_id(self, caller_id):
        """
        Sets the caller_id of this Identity.
        The `OCID`__ of the caller. The caller that made a
        request on behalf of the prinicpal.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param caller_id: The caller_id of this Identity.
        :type: str
        """
        self._caller_id = caller_id

    @property
    def tenant_id(self):
        """
        Gets the tenant_id of this Identity.
        The `OCID`__ of the tenant.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The tenant_id of this Identity.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this Identity.
        The `OCID`__ of the tenant.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param tenant_id: The tenant_id of this Identity.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def ip_address(self):
        """
        Gets the ip_address of this Identity.
        The IP address of the source of the request.

        Example: `172.24.80.88`


        :return: The ip_address of this Identity.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this Identity.
        The IP address of the source of the request.

        Example: `172.24.80.88`


        :param ip_address: The ip_address of this Identity.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def credentials(self):
        """
        Gets the credentials of this Identity.
        The credential ID of the user. This value is extracted from the HTTP 'Authorization' request
        header. It consists of the tenantId, userId, and user fingerprint, all delimited by a slash (/).


        :return: The credentials of this Identity.
        :rtype: str
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """
        Sets the credentials of this Identity.
        The credential ID of the user. This value is extracted from the HTTP 'Authorization' request
        header. It consists of the tenantId, userId, and user fingerprint, all delimited by a slash (/).


        :param credentials: The credentials of this Identity.
        :type: str
        """
        self._credentials = credentials

    @property
    def user_agent(self):
        """
        Gets the user_agent of this Identity.
        The user agent of the client that made the request.

        Example: `Jersey/2.23 (HttpUrlConnection 1.8.0_212)`


        :return: The user_agent of this Identity.
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """
        Sets the user_agent of this Identity.
        The user agent of the client that made the request.

        Example: `Jersey/2.23 (HttpUrlConnection 1.8.0_212)`


        :param user_agent: The user_agent of this Identity.
        :type: str
        """
        self._user_agent = user_agent

    @property
    def console_session_id(self):
        """
        Gets the console_session_id of this Identity.
        This value identifies any Console session associated with this request.


        :return: The console_session_id of this Identity.
        :rtype: str
        """
        return self._console_session_id

    @console_session_id.setter
    def console_session_id(self, console_session_id):
        """
        Sets the console_session_id of this Identity.
        This value identifies any Console session associated with this request.


        :param console_session_id: The console_session_id of this Identity.
        :type: str
        """
        self._console_session_id = console_session_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiSpecification(object):
    """
    The logical configuration of the API exposed by a deployment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApiSpecification object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param request_policies:
            The value to assign to the request_policies property of this ApiSpecification.
        :type request_policies: ApiSpecificationRequestPolicies

        :param logging_policies:
            The value to assign to the logging_policies property of this ApiSpecification.
        :type logging_policies: ApiSpecificationLoggingPolicies

        :param routes:
            The value to assign to the routes property of this ApiSpecification.
        :type routes: list[ApiSpecificationRoute]

        """
        self.swagger_types = {
            'request_policies': 'ApiSpecificationRequestPolicies',
            'logging_policies': 'ApiSpecificationLoggingPolicies',
            'routes': 'list[ApiSpecificationRoute]'
        }

        self.attribute_map = {
            'request_policies': 'requestPolicies',
            'logging_policies': 'loggingPolicies',
            'routes': 'routes'
        }

        self._request_policies = None
        self._logging_policies = None
        self._routes = None

    @property
    def request_policies(self):
        """
        Gets the request_policies of this ApiSpecification.

        :return: The request_policies of this ApiSpecification.
        :rtype: ApiSpecificationRequestPolicies
        """
        return self._request_policies

    @request_policies.setter
    def request_policies(self, request_policies):
        """
        Sets the request_policies of this ApiSpecification.

        :param request_policies: The request_policies of this ApiSpecification.
        :type: ApiSpecificationRequestPolicies
        """
        self._request_policies = request_policies

    @property
    def logging_policies(self):
        """
        Gets the logging_policies of this ApiSpecification.

        :return: The logging_policies of this ApiSpecification.
        :rtype: ApiSpecificationLoggingPolicies
        """
        return self._logging_policies

    @logging_policies.setter
    def logging_policies(self, logging_policies):
        """
        Sets the logging_policies of this ApiSpecification.

        :param logging_policies: The logging_policies of this ApiSpecification.
        :type: ApiSpecificationLoggingPolicies
        """
        self._logging_policies = logging_policies

    @property
    def routes(self):
        """
        Gets the routes of this ApiSpecification.
        A list of routes that this API exposes.


        :return: The routes of this ApiSpecification.
        :rtype: list[ApiSpecificationRoute]
        """
        return self._routes

    @routes.setter
    def routes(self, routes):
        """
        Sets the routes of this ApiSpecification.
        A list of routes that this API exposes.


        :param routes: The routes of this ApiSpecification.
        :type: list[ApiSpecificationRoute]
        """
        self._routes = routes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AppCatalogListingResourceVersionSummary(object):
    """
    Listing Resource Version summary
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AppCatalogListingResourceVersionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param listing_id:
            The value to assign to the listing_id property of this AppCatalogListingResourceVersionSummary.
        :type listing_id: str

        :param time_published:
            The value to assign to the time_published property of this AppCatalogListingResourceVersionSummary.
        :type time_published: datetime

        :param listing_resource_id:
            The value to assign to the listing_resource_id property of this AppCatalogListingResourceVersionSummary.
        :type listing_resource_id: str

        :param listing_resource_version:
            The value to assign to the listing_resource_version property of this AppCatalogListingResourceVersionSummary.
        :type listing_resource_version: str

        """
        self.swagger_types = {
            'listing_id': 'str',
            'time_published': 'datetime',
            'listing_resource_id': 'str',
            'listing_resource_version': 'str'
        }

        self.attribute_map = {
            'listing_id': 'listingId',
            'time_published': 'timePublished',
            'listing_resource_id': 'listingResourceId',
            'listing_resource_version': 'listingResourceVersion'
        }

        self._listing_id = None
        self._time_published = None
        self._listing_resource_id = None
        self._listing_resource_version = None

    @property
    def listing_id(self):
        """
        Gets the listing_id of this AppCatalogListingResourceVersionSummary.
        The OCID of the listing this resource version belongs to.


        :return: The listing_id of this AppCatalogListingResourceVersionSummary.
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """
        Sets the listing_id of this AppCatalogListingResourceVersionSummary.
        The OCID of the listing this resource version belongs to.


        :param listing_id: The listing_id of this AppCatalogListingResourceVersionSummary.
        :type: str
        """
        self._listing_id = listing_id

    @property
    def time_published(self):
        """
        Gets the time_published of this AppCatalogListingResourceVersionSummary.
        Date and time the listing resource version was published, in `RFC3339`__ format.
        Example: `2018-03-20T12:32:53.532Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_published of this AppCatalogListingResourceVersionSummary.
        :rtype: datetime
        """
        return self._time_published

    @time_published.setter
    def time_published(self, time_published):
        """
        Sets the time_published of this AppCatalogListingResourceVersionSummary.
        Date and time the listing resource version was published, in `RFC3339`__ format.
        Example: `2018-03-20T12:32:53.532Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_published: The time_published of this AppCatalogListingResourceVersionSummary.
        :type: datetime
        """
        self._time_published = time_published

    @property
    def listing_resource_id(self):
        """
        Gets the listing_resource_id of this AppCatalogListingResourceVersionSummary.
        OCID of the listing resource.


        :return: The listing_resource_id of this AppCatalogListingResourceVersionSummary.
        :rtype: str
        """
        return self._listing_resource_id

    @listing_resource_id.setter
    def listing_resource_id(self, listing_resource_id):
        """
        Sets the listing_resource_id of this AppCatalogListingResourceVersionSummary.
        OCID of the listing resource.


        :param listing_resource_id: The listing_resource_id of this AppCatalogListingResourceVersionSummary.
        :type: str
        """
        self._listing_resource_id = listing_resource_id

    @property
    def listing_resource_version(self):
        """
        Gets the listing_resource_version of this AppCatalogListingResourceVersionSummary.
        Resource Version.


        :return: The listing_resource_version of this AppCatalogListingResourceVersionSummary.
        :rtype: str
        """
        return self._listing_resource_version

    @listing_resource_version.setter
    def listing_resource_version(self, listing_resource_version):
        """
        Sets the listing_resource_version of this AppCatalogListingResourceVersionSummary.
        Resource Version.


        :param listing_resource_version: The listing_resource_version of this AppCatalogListingResourceVersionSummary.
        :type: str
        """
        self._listing_resource_version = listing_resource_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

from .enums import ProbingState
from .charsetprober import CharSetProber


class CharSetGroupProber(CharSetProber):
    def __init__(self, lang_filter=None):
        super(CharSetGroupProber, self).__init__(lang_filter=lang_filter)
        self._active_num = 0
        self.probers = []
        self._best_guess_prober = None

    def reset(self):
        super(CharSetGroupProber, self).reset()
        self._active_num = 0
        for prober in self.probers:
            if prober:
                prober.reset()
                prober.active = True
                self._active_num += 1
        self._best_guess_prober = None

    @property
    def charset_name(self):
        if not self._best_guess_prober:
            self.get_confidence()
            if not self._best_guess_prober:
                return None
        return self._best_guess_prober.charset_name

    @property
    def language(self):
        if not self._best_guess_prober:
            self.get_confidence()
            if not self._best_guess_prober:
                return None
        return self._best_guess_prober.language

    def feed(self, byte_str):
        for prober in self.probers:
            if not prober:
                continue
            if not prober.active:
                continue
            state = prober.feed(byte_str)
            if not state:
                continue
            if state == ProbingState.FOUND_IT:
                self._best_guess_prober = prober
                return self.state
            elif state == ProbingState.NOT_ME:
                prober.active = False
                self._active_num -= 1
                if self._active_num <= 0:
                    self._state = ProbingState.NOT_ME
                    return self.state
        return self.state

    def get_confidence(self):
        state = self.state
        if state == ProbingState.FOUND_IT:
            return 0.99
        elif state == ProbingState.NOT_ME:
            return 0.01
        best_conf = 0.0
        self._best_guess_prober = None
        for prober in self.probers:
            if not prober:
                continue
            if not prober.active:
                self.logger.debug('%s not active', prober.charset_name)
                continue
            conf = prober.get_confidence()
            self.logger.debug('%s %s confidence = %s', prober.charset_name, prober.language, conf)
            if best_conf < conf:
                best_conf = conf
                self._best_guess_prober = prober
        if not self._best_guess_prober:
            return 0.0
        return best_conf



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDatabaseDetails(object):
    """
    Details for creating a database.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the db_workload property of a CreateDatabaseDetails.
    #: This constant has a value of "OLTP"
    DB_WORKLOAD_OLTP = "OLTP"

    #: A constant which can be used with the db_workload property of a CreateDatabaseDetails.
    #: This constant has a value of "DSS"
    DB_WORKLOAD_DSS = "DSS"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param db_name:
            The value to assign to the db_name property of this CreateDatabaseDetails.
        :type db_name: str

        :param db_unique_name:
            The value to assign to the db_unique_name property of this CreateDatabaseDetails.
        :type db_unique_name: str

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this CreateDatabaseDetails.
        :type database_software_image_id: str

        :param pdb_name:
            The value to assign to the pdb_name property of this CreateDatabaseDetails.
        :type pdb_name: str

        :param admin_password:
            The value to assign to the admin_password property of this CreateDatabaseDetails.
        :type admin_password: str

        :param character_set:
            The value to assign to the character_set property of this CreateDatabaseDetails.
        :type character_set: str

        :param ncharacter_set:
            The value to assign to the ncharacter_set property of this CreateDatabaseDetails.
        :type ncharacter_set: str

        :param db_workload:
            The value to assign to the db_workload property of this CreateDatabaseDetails.
            Allowed values for this property are: "OLTP", "DSS"
        :type db_workload: str

        :param db_backup_config:
            The value to assign to the db_backup_config property of this CreateDatabaseDetails.
        :type db_backup_config: DbBackupConfig

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDatabaseDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDatabaseDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'db_name': 'str',
            'db_unique_name': 'str',
            'database_software_image_id': 'str',
            'pdb_name': 'str',
            'admin_password': 'str',
            'character_set': 'str',
            'ncharacter_set': 'str',
            'db_workload': 'str',
            'db_backup_config': 'DbBackupConfig',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'db_name': 'dbName',
            'db_unique_name': 'dbUniqueName',
            'database_software_image_id': 'databaseSoftwareImageId',
            'pdb_name': 'pdbName',
            'admin_password': 'adminPassword',
            'character_set': 'characterSet',
            'ncharacter_set': 'ncharacterSet',
            'db_workload': 'dbWorkload',
            'db_backup_config': 'dbBackupConfig',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._db_name = None
        self._db_unique_name = None
        self._database_software_image_id = None
        self._pdb_name = None
        self._admin_password = None
        self._character_set = None
        self._ncharacter_set = None
        self._db_workload = None
        self._db_backup_config = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def db_name(self):
        """
        **[Required]** Gets the db_name of this CreateDatabaseDetails.
        The database name. The name must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.


        :return: The db_name of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """
        Sets the db_name of this CreateDatabaseDetails.
        The database name. The name must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.


        :param db_name: The db_name of this CreateDatabaseDetails.
        :type: str
        """
        self._db_name = db_name

    @property
    def db_unique_name(self):
        """
        Gets the db_unique_name of this CreateDatabaseDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :return: The db_unique_name of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this CreateDatabaseDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :param db_unique_name: The db_unique_name of this CreateDatabaseDetails.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def database_software_image_id(self):
        """
        Gets the database_software_image_id of this CreateDatabaseDetails.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_software_image_id of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._database_software_image_id

    @database_software_image_id.setter
    def database_software_image_id(self, database_software_image_id):
        """
        Sets the database_software_image_id of this CreateDatabaseDetails.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_software_image_id: The database_software_image_id of this CreateDatabaseDetails.
        :type: str
        """
        self._database_software_image_id = database_software_image_id

    @property
    def pdb_name(self):
        """
        Gets the pdb_name of this CreateDatabaseDetails.
        The name of the pluggable database. The name must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted. Pluggable database should not be same as database name.


        :return: The pdb_name of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._pdb_name

    @pdb_name.setter
    def pdb_name(self, pdb_name):
        """
        Sets the pdb_name of this CreateDatabaseDetails.
        The name of the pluggable database. The name must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted. Pluggable database should not be same as database name.


        :param pdb_name: The pdb_name of this CreateDatabaseDetails.
        :type: str
        """
        self._pdb_name = pdb_name

    @property
    def admin_password(self):
        """
        **[Required]** Gets the admin_password of this CreateDatabaseDetails.
        A strong password for SYS, SYSTEM, and PDB Admin. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :return: The admin_password of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """
        Sets the admin_password of this CreateDatabaseDetails.
        A strong password for SYS, SYSTEM, and PDB Admin. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :param admin_password: The admin_password of this CreateDatabaseDetails.
        :type: str
        """
        self._admin_password = admin_password

    @property
    def character_set(self):
        """
        Gets the character_set of this CreateDatabaseDetails.
        The character set for the database.  The default is AL32UTF8. Allowed values are:

        AL32UTF8, AR8ADOS710, AR8ADOS720, AR8APTEC715, AR8ARABICMACS, AR8ASMO8X, AR8ISO8859P6, AR8MSWIN1256, AR8MUSSAD768, AR8NAFITHA711, AR8NAFITHA721, AR8SAKHR706, AR8SAKHR707, AZ8ISO8859P9E, BG8MSWIN, BG8PC437S, BLT8CP921, BLT8ISO8859P13, BLT8MSWIN1257, BLT8PC775, BN8BSCII, CDN8PC863, CEL8ISO8859P14, CL8ISO8859P5, CL8ISOIR111, CL8KOI8R, CL8KOI8U, CL8MACCYRILLICS, CL8MSWIN1251, EE8ISO8859P2, EE8MACCES, EE8MACCROATIANS, EE8MSWIN1250, EE8PC852, EL8DEC, EL8ISO8859P7, EL8MACGREEKS, EL8MSWIN1253, EL8PC437S, EL8PC851, EL8PC869, ET8MSWIN923, HU8ABMOD, HU8CWI2, IN8ISCII, IS8PC861, IW8ISO8859P8, IW8MACHEBREWS, IW8MSWIN1255, IW8PC1507, JA16EUC, JA16EUCTILDE, JA16SJIS, JA16SJISTILDE, JA16VMS, KO16KSC5601, KO16KSCCS, KO16MSWIN949, LA8ISO6937, LA8PASSPORT, LT8MSWIN921, LT8PC772, LT8PC774, LV8PC1117, LV8PC8LR, LV8RST104090, N8PC865, NE8ISO8859P10, NEE8ISO8859P4, RU8BESTA, RU8PC855, RU8PC866, SE8ISO8859P3, TH8MACTHAIS, TH8TISASCII, TR8DEC, TR8MACTURKISHS, TR8MSWIN1254, TR8PC857, US7ASCII, US8PC437, UTF8, VN8MSWIN1258, VN8VN3, WE8DEC, WE8DG, WE8ISO8859P1, WE8ISO8859P15, WE8ISO8859P9, WE8MACROMAN8S, WE8MSWIN1252, WE8NCR4970, WE8NEXTSTEP, WE8PC850, WE8PC858, WE8PC860, WE8ROMAN8, ZHS16CGB231280, ZHS16GBK, ZHT16BIG5, ZHT16CCDC, ZHT16DBT, ZHT16HKSCS, ZHT16MSWIN950, ZHT32EUC, ZHT32SOPS, ZHT32TRIS


        :return: The character_set of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._character_set

    @character_set.setter
    def character_set(self, character_set):
        """
        Sets the character_set of this CreateDatabaseDetails.
        The character set for the database.  The default is AL32UTF8. Allowed values are:

        AL32UTF8, AR8ADOS710, AR8ADOS720, AR8APTEC715, AR8ARABICMACS, AR8ASMO8X, AR8ISO8859P6, AR8MSWIN1256, AR8MUSSAD768, AR8NAFITHA711, AR8NAFITHA721, AR8SAKHR706, AR8SAKHR707, AZ8ISO8859P9E, BG8MSWIN, BG8PC437S, BLT8CP921, BLT8ISO8859P13, BLT8MSWIN1257, BLT8PC775, BN8BSCII, CDN8PC863, CEL8ISO8859P14, CL8ISO8859P5, CL8ISOIR111, CL8KOI8R, CL8KOI8U, CL8MACCYRILLICS, CL8MSWIN1251, EE8ISO8859P2, EE8MACCES, EE8MACCROATIANS, EE8MSWIN1250, EE8PC852, EL8DEC, EL8ISO8859P7, EL8MACGREEKS, EL8MSWIN1253, EL8PC437S, EL8PC851, EL8PC869, ET8MSWIN923, HU8ABMOD, HU8CWI2, IN8ISCII, IS8PC861, IW8ISO8859P8, IW8MACHEBREWS, IW8MSWIN1255, IW8PC1507, JA16EUC, JA16EUCTILDE, JA16SJIS, JA16SJISTILDE, JA16VMS, KO16KSC5601, KO16KSCCS, KO16MSWIN949, LA8ISO6937, LA8PASSPORT, LT8MSWIN921, LT8PC772, LT8PC774, LV8PC1117, LV8PC8LR, LV8RST104090, N8PC865, NE8ISO8859P10, NEE8ISO8859P4, RU8BESTA, RU8PC855, RU8PC866, SE8ISO8859P3, TH8MACTHAIS, TH8TISASCII, TR8DEC, TR8MACTURKISHS, TR8MSWIN1254, TR8PC857, US7ASCII, US8PC437, UTF8, VN8MSWIN1258, VN8VN3, WE8DEC, WE8DG, WE8ISO8859P1, WE8ISO8859P15, WE8ISO8859P9, WE8MACROMAN8S, WE8MSWIN1252, WE8NCR4970, WE8NEXTSTEP, WE8PC850, WE8PC858, WE8PC860, WE8ROMAN8, ZHS16CGB231280, ZHS16GBK, ZHT16BIG5, ZHT16CCDC, ZHT16DBT, ZHT16HKSCS, ZHT16MSWIN950, ZHT32EUC, ZHT32SOPS, ZHT32TRIS


        :param character_set: The character_set of this CreateDatabaseDetails.
        :type: str
        """
        self._character_set = character_set

    @property
    def ncharacter_set(self):
        """
        Gets the ncharacter_set of this CreateDatabaseDetails.
        The national character set for the database.  The default is AL16UTF16. Allowed values are:
        AL16UTF16 or UTF8.


        :return: The ncharacter_set of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._ncharacter_set

    @ncharacter_set.setter
    def ncharacter_set(self, ncharacter_set):
        """
        Sets the ncharacter_set of this CreateDatabaseDetails.
        The national character set for the database.  The default is AL16UTF16. Allowed values are:
        AL16UTF16 or UTF8.


        :param ncharacter_set: The ncharacter_set of this CreateDatabaseDetails.
        :type: str
        """
        self._ncharacter_set = ncharacter_set

    @property
    def db_workload(self):
        """
        Gets the db_workload of this CreateDatabaseDetails.
        The database workload type.

        Allowed values for this property are: "OLTP", "DSS"


        :return: The db_workload of this CreateDatabaseDetails.
        :rtype: str
        """
        return self._db_workload

    @db_workload.setter
    def db_workload(self, db_workload):
        """
        Sets the db_workload of this CreateDatabaseDetails.
        The database workload type.


        :param db_workload: The db_workload of this CreateDatabaseDetails.
        :type: str
        """
        allowed_values = ["OLTP", "DSS"]
        if not value_allowed_none_or_none_sentinel(db_workload, allowed_values):
            raise ValueError(
                "Invalid value for `db_workload`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._db_workload = db_workload

    @property
    def db_backup_config(self):
        """
        Gets the db_backup_config of this CreateDatabaseDetails.

        :return: The db_backup_config of this CreateDatabaseDetails.
        :rtype: DbBackupConfig
        """
        return self._db_backup_config

    @db_backup_config.setter
    def db_backup_config(self, db_backup_config):
        """
        Sets the db_backup_config of this CreateDatabaseDetails.

        :param db_backup_config: The db_backup_config of this CreateDatabaseDetails.
        :type: DbBackupConfig
        """
        self._db_backup_config = db_backup_config

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateDatabaseDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateDatabaseDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateDatabaseDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateDatabaseDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
